ardt.datasets.cuads.CuadsTrial
==============================

.. currentmodule:: ardt.datasets.cuads

.. autoclass:: CuadsTrial

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CuadsTrial.__init__
      ~CuadsTrial.get_signal_metadata
      ~CuadsTrial.load_ground_truth
      ~CuadsTrial.load_preprocessed_signal_data
      ~CuadsTrial.load_signal_data
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CuadsTrial.dataset
      ~CuadsTrial.expected_response
      ~CuadsTrial.media_id
      ~CuadsTrial.media_name
      ~CuadsTrial.participant_id
      ~CuadsTrial.signal_data_files
      ~CuadsTrial.signal_preprocessors
      ~CuadsTrial.signal_types
   
   